@@ -1,5 +1,5 @@
 /* communications.c -- Send commands to a running copy of ratpoison.
- * Copyright (C) 2000, 2001, 2002, 2003 Shawn Betts
+ * Copyright (C) 2000, 2001, 2002, 2003, 2004 Shawn Betts <sabetts@vcn.bc.ca>
  *
  * This file is part of ratpoison.
  *
@@ -12,7 +12,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
@@ -43,9 +43,9 @@ receive_command_result (Window w)
 
   /* First, find out how big the property is. */
   status = XGetWindowProperty (dpy, w, rp_command_result,
-			       0, 0, False, XA_STRING,
-			       &type_ret, &format_ret, &nitems, &bytes_after,
-			       &result);
+                               0, 0, False, XA_STRING,
+                               &type_ret, &format_ret, &nitems, &bytes_after,
+                               &result);
 
   /* Failed to retrieve property. */
   if (status != Success || result == NULL)
@@ -61,9 +61,9 @@ receive_command_result (Window w)
   /* Now that we have the length of the message, we can get the
      whole message. */
   status = XGetWindowProperty (dpy, w, rp_command_result,
-			       0, (bytes_after / 4) + (bytes_after % 4 ? 1 : 0),
-			       True, XA_STRING, &type_ret, &format_ret, &nitems, 
-			       &bytes_after, &result);
+                               0, (bytes_after / 4) + (bytes_after % 4 ? 1 : 0),
+                               True, XA_STRING, &type_ret, &format_ret, &nitems,
+                               &bytes_after, &result);
 
   /* Failed to retrieve property. */
   if (status != Success || result == NULL)
@@ -73,8 +73,13 @@ receive_command_result (Window w)
     }
 
   /* If result is not the empty string, print it. */
-  if (strlen (result))
-    printf ("%s\n", result);
+  if (strlen ((char *)result))
+    {
+      if (result[0] == '1')
+        printf ("%s\n", &result[1]);
+      else
+        fprintf (stderr, "%s\n", &result[1]);
+    }
 
   /* Free the result. */
   XFree (result);
@@ -83,7 +88,7 @@ receive_command_result (Window w)
 int
 send_command (unsigned char interactive, unsigned char *cmd, int screen_num)
 {
-  Window w;
+  Window w, root;
   int done = 0;
   struct sbuf *s;
 
@@ -94,25 +99,21 @@ send_command (unsigned char interactive, unsigned char *cmd, int screen_num)
   /* If the user specified a specific screen, then send the event to
      that screen. */
   if (screen_num >= 0)
-    {
-      w = XCreateSimpleWindow (dpy, RootWindow (dpy, screen_num),
-			       0, 0, 1, 1, 0, 0, 0);
-    }
+    root = RootWindow (dpy, screen_num);
   else
-    {
-      w = XCreateSimpleWindow (dpy, DefaultRootWindow (dpy),
-			       0, 0, 1, 1, 0, 0, 0);
-    }
+    root = DefaultRootWindow (dpy);
+
+  w = XCreateSimpleWindow (dpy, root, 0, 0, 1, 1, 0, 0, 0);
 
   /* Select first to avoid race condition */
   XSelectInput (dpy, w, PropertyChangeMask);
 
   XChangeProperty (dpy, w, rp_command, XA_STRING,
-		   8, PropModeReplace, sbuf_get(s), strlen (cmd) + 2);
+                   8, PropModeReplace, sbuf_get(s), strlen ((char *)cmd) + 2);
 
-  XChangeProperty (dpy, DefaultRootWindow (dpy), 
-		   rp_command_request, XA_WINDOW,
-		   8, PropModeAppend, (unsigned char *)&w, sizeof (Window));
+  XChangeProperty (dpy, root,
+                   rp_command_request, XA_WINDOW,
+                   8, PropModeAppend, (unsigned char *)&w, sizeof (Window));
 
   sbuf_free (s);
 
@@ -121,12 +122,12 @@ send_command (unsigned char interactive, unsigned char *cmd, int screen_num)
       XEvent ev;
 
       XMaskEvent (dpy, PropertyChangeMask, &ev);
-      if (ev.xproperty.atom == rp_command_result 
-	  && ev.xproperty.state == PropertyNewValue)
-	{
-	  receive_command_result(ev.xproperty.window);
-	  done = 1;
-	}
+      if (ev.xproperty.atom == rp_command_result
+          && ev.xproperty.state == PropertyNewValue)
+        {
+          receive_command_result(ev.xproperty.window);
+          done = 1;
+        }
     }
 
   XDestroyWindow (dpy, w);
