@@ -151,7 +151,7 @@ struct rp_group
 
 struct rp_screen
 {
-  GC normal_gc;
+  GC normal_gc, inverse_gc;
   Window root, bar_window, key_window, input_window, frame_window, help_window;
   int bar_is_raised;
   int screen_num;               /* Our screen number as dictated my X */
@@ -177,8 +177,8 @@ struct rp_screen
   int current_frame;
 
 #ifdef USE_XFT_FONT
-  XftFont *ft_font;
-  XftColor color;
+  XftFont *xft_font;
+  XftColor xft_fg_color, xft_bg_color;
 #endif
 };
 
