@@ -56,9 +56,7 @@ static edit_status editor_complete_next (rp_input_line *line);
 static edit_status editor_insert (rp_input_line *line, char *keysym_buf);
 
 
-#ifdef HAVE_HISTORY
 static char *saved_command = NULL;
-#endif
 
 typedef struct edit_binding edit_binding;
 
@@ -102,13 +100,14 @@ static edit_binding edit_bindings[] =
      { {0,              0},     0} };
 
 rp_input_line *
-input_line_new (char *prompt, char *preinput, completion_fn fn)
+input_line_new (char *prompt, char *preinput, int history_id, completion_fn fn)
 {
   rp_input_line *line;
 
   line = xmalloc (sizeof (rp_input_line));
   line->prompt = prompt;
   line->compl = completions_new (fn);
+  line->history_id = history_id;
 
   /* Allocate some memory to start with */
   line->size = strlen (preinput) + 100;
@@ -357,8 +356,7 @@ editor_backward_kill_line (rp_input_line *line)
 static edit_status
 editor_history_previous (rp_input_line *line)
 {
-#ifdef HAVE_HISTORY
-  char *entry = history_previous ();
+  const char *entry = history_previous (line->history_id);
 
   if (entry)
     {
@@ -383,19 +381,12 @@ editor_history_previous (rp_input_line *line)
     }
 
   return EDIT_INSERT;
-
-#else  /* HAVE_HISTORY */
-
-  return EDIT_NO_OP;
-
-#endif /* HAVE_HISTORY */
 }
 
 static edit_status
 editor_history_next (rp_input_line *line)
 {
-#ifdef HAVE_HISTORY
-  char *entry = history_next ();
+  const char *entry = history_next (line->history_id);
 
   if (entry)
     {
@@ -421,10 +412,6 @@ editor_history_next (rp_input_line *line)
   line->position = line->length;
 
   return EDIT_INSERT;
-
-#else  /* HAVE_HISTORY */
-  return EDIT_NO_OP;
-#endif /* HAVE_HISTORY */
 }
 
 static edit_status
@@ -466,14 +453,17 @@ editor_insert (rp_input_line *line, char *keysym_buf)
 static edit_status
 editor_enter (rp_input_line *line)
 {
-#ifdef HAVE_HISTORY
   int result;
   char *expansion;
-#endif
 
   line->buffer[line->length] = '\0';
-#ifdef HAVE_HISTORY
-  result = history_expand_line (line->buffer, &expansion);
+
+  if (!defaults.history_expansion) {
+      history_add (line->history_id, line->buffer);
+      return EDIT_DONE;
+  }
+
+  result = history_expand_line (line->history_id, line->buffer, &expansion);
 
   PRINT_DEBUG (("History Expansion - result: %d\n", result));
   PRINT_DEBUG (("History Expansion - expansion: \'%s\'\n", expansion));
@@ -486,11 +476,10 @@ editor_enter (rp_input_line *line)
     }
   else /* result == 0 || result == 1 */
     {
-      history_add (expansion);
+      history_add (line->history_id, expansion);
       free (line->buffer);
       line->buffer = expansion;
     }
-#endif /* HAVE_HISTORY */
 
   return EDIT_DONE;
 }
