@@ -774,17 +774,20 @@ free_screen (rp_screen *s)
   XDestroyWindow (dpy, s->help_window);
 
 #ifdef USE_XFT_FONT
-  if (s->ft_font)
+  if (s->xft_font)
     {
       XftColorFree (dpy, DefaultVisual (dpy, s->screen_num),
-                    DefaultColormap (dpy, s->screen_num), &s->color);
-      XftFontClose (dpy, s->ft_font);
+                    DefaultColormap (dpy, s->screen_num), &s->xft_fg_color);
+      XftColorFree (dpy, DefaultVisual (dpy, s->screen_num),
+                    DefaultColormap (dpy, s->screen_num), &s->xft_bg_color);
+      XftFontClose (dpy, s->xft_font);
     }
 #endif
 
   XFreeCursor (dpy, s->rat);
   XFreeColormap (dpy, s->def_cmap);
   XFreeGC (dpy, s->normal_gc);
+  XFreeGC (dpy, s->inverse_gc);
 
   free (s->display_string);
 }
