@@ -317,6 +317,32 @@ window_is_transient (rp_window *win)
     ;
 }
 
+static Atom
+get_net_wm_window_type (rp_window *win)
+{
+  Atom type, window_type = None;
+  int format;
+  unsigned long nitems;
+  unsigned long bytes_left;
+  unsigned char *data;
+
+  if (win == NULL)
+    return None;
+
+  if (XGetWindowProperty (dpy, win->w, _net_wm_window_type, 0, 1L,
+                          False, XA_ATOM, &type, &format,
+                          &nitems, &bytes_left,
+                          &data) == Success && nitems > 0)
+    {
+      window_type = *(Atom *)data;
+      XFree (data);
+      PRINT_DEBUG(("hey ya %ld %ld\n", window_type, _net_wm_window_type_dialog));
+    }
+
+  return window_type;
+}
+
+
 void
 update_window_information (rp_window *win)
 {
@@ -339,6 +365,9 @@ update_window_information (rp_window *win)
   /* Transient status */
   win->transient = XGetTransientForHint (dpy, win->w, &win->transient_for);
 
+  if (get_net_wm_window_type(win) == _net_wm_window_type_dialog)
+    win->transient = 1;
+
   update_window_gravity (win);
 }
 
@@ -351,8 +380,8 @@ unmanage (rp_window *w)
   free_window (w);
 
 #ifdef AUTO_CLOSE
-  if (rp_mapped_window->next == &rp_mapped_window
-      && rp_mapped_window->prev == &rp_mapped_window)
+  if (rp_mapped_window.next == &rp_mapped_window
+      && rp_mapped_window.prev == &rp_mapped_window)
     {
       /* If the mapped window list is empty then we have run out of
          managed windows, so kill ratpoison. */
@@ -800,6 +829,9 @@ hide_window (rp_window *win)
   XSelectInput(dpy, win->w, WIN_EVENTS&~(StructureNotifyMask));
   XUnmapWindow (dpy, win->w);
   XSelectInput (dpy, win->w, WIN_EVENTS);
+  /* Ensure that the window doesn't have the focused border
+     color. This is needed by remove_frame and possibly others. */
+  XSetWindowBorder (dpy, win->w, win->scr->bw_color);
   set_state (win, IconicState);
 }
 
