@@ -36,6 +36,8 @@
 #define MESSAGE_RAISE_WINDOW_GROUP      "Raise request from window %d (%s) in group %s"
 #define MESSAGE_MAP_TRANSIENT           "New transient window %d (%s)"
 #define MESSAGE_MAP_WINDOW              "New window %d (%s)"
+#define MESSAGE_MAP_TRANSIENT_GROUP     "New transient window %d (%s) in group %s"
+#define MESSAGE_MAP_WINDOW_GROUP        "New window %d (%s) in group %s"
 
 #define MESSAGE_PROMPT_SWITCH_TO_WINDOW "Switch to window: "
 #define MESSAGE_PROMPT_NEW_WINDOW_NAME  "Set window's title to: "
@@ -48,6 +50,7 @@
 #define MESSAGE_PROMPT_VAR_VALUE  "Value: "
 
 #define MESSAGE_WELCOME "Welcome to ratpoison! Hit `%s %s' for help."
-#define MESSAGE_FRAME_STRING    "Current Frame"
+
+#define EMPTY_FRAME_MESSAGE "Current Frame"
 
 #endif /* ! _RATPOISON_MESSAGES_H */
