@@ -82,9 +82,7 @@ extern XGCValues gv;
 #include "screen.h"
 #include "group.h"
 #include "editor.h"
-#ifdef HAVE_HISTORY
 #include "history.h"
-#endif /* HAVE_HISTORY */
 #include "completions.h"
 #include "hook.h"
 #include "xinerama.h"
@@ -99,7 +97,7 @@ void read_rc_file (FILE *file);
 void fatal (const char *msg);
 void *xmalloc (size_t size);
 void *xrealloc (void *ptr, size_t size);
-char *xstrdup (char *s);
+char *xstrdup (const char *s);
 char *xsprintf (char *fmt, ...);
 char *xvsprintf (char *fmt, va_list ap);
 int str_comp (char *s1, char *s2, int len);
